aboutsummaryrefslogtreecommitdiff
path: root/lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2003-05-08 16:18:31 +0000
committerChris Lattner <sabre@nondot.org>2003-05-08 16:18:31 +0000
commitda82ed52ac02497d343b898cca0bb2cf303f062d (patch)
treea30e76da9aaa7ff025a59804315b601994bd6ca3 /lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h
parentcdf5178f8362b0b415a4e1c1378a5b76638826be (diff)
A large number of simple changes:
* s/Method/Function * Kill some obsolete (external) functions that used to be to support tracing git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@6041 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h')
-rw-r--r--lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h19
1 files changed, 9 insertions, 10 deletions
diff --git a/lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h b/lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h
index 1a5c7fee98..25b31cd8b4 100644
--- a/lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h
+++ b/lib/ExecutionEngine/Interpreter/ExecutionAnnotations.h
@@ -8,7 +8,7 @@
#define LLI_EXECUTION_ANNOTATIONS_H
//===----------------------------------------------------------------------===//
// Support for MethodInfo annotations
//===----------------------------------------------------------------------===//
// This annotation (attached only to Function objects) is used to cache useful
@@ -18,20 +18,19 @@
// This annotation object is created on demand, and attaches other annotation
// objects to the instructions in the function when it's created.
//
-static AnnotationID MethodInfoAID(
+static AnnotationID FunctionInfoAID(
AnnotationManager::getID("Interpreter::FunctionInfo"));
-struct MethodInfo : public Annotation {
- MethodInfo(Function *F);
+struct FunctionInfo : public Annotation {
+ FunctionInfo(Function *F);
std::vector<unsigned> NumPlaneElements;
-
- // Create - Factory function to allow MethodInfo annotations to be
+ // Create - Factory function to allow FunctionInfo annotations to be
// created on demand.
//
static Annotation *Create(AnnotationID AID, const Annotable *O, void *) {
- assert(AID == MethodInfoAID);
- return new MethodInfo(cast<Function>((Value*)O)); // Simply invoke the ctor
+ assert(AID == FunctionInfoAID);
+ return new FunctionInfo(cast<Function>((Value*)O));
}
private:
@@ -47,7 +46,7 @@ private:
// hold the the slot number for the value in its type plane.
//
// Entities have this annotation attached to them when the containing
// function has it's MethodInfo created (by the MethodInfo ctor).
//
static AnnotationID SlotNumberAID(
AnnotationManager::getID("Interpreter::SlotNumber"));
@@ -72,7 +71,7 @@ struct SlotNumber : public Annotation {
// calculating which value slot to store the result of the instruction in.
//
// Instructions have this annotation attached to them when the containing
// function has it's MethodInfo created (by the MethodInfo ctor).
//
struct InstNumber : public SlotNumber {
unsigned InstNum; // Ranges from 1->
@@ -8,7 +8,7 @@
#define LLI_EXECUTION_ANNOTATIONS_H
//===----------------------------------------------------------------------===//
-// Support for MethodInfo annotations
+// Support for FunctionInfo annotations
//===----------------------------------------------------------------------===//
// This annotation (attached only to Function objects) is used to cache useful
@@ -47,7 +46,7 @@ private:
//
// Entities have this annotation attached to them when the containing
-// function has it's MethodInfo created (by the MethodInfo ctor).
+// function has it's FunctionInfo created (by the FunctionInfo ctor).
//
static AnnotationID SlotNumberAID(
@@ -72,7 +71,7 @@ struct SlotNumber : public Annotation {
//
// Instructions have this annotation attached to them when the containing
-// function has it's MethodInfo created (by the MethodInfo ctor).
+// function has it's FunctionInfo created (by the FunctionInfo ctor).
//
struct InstNumber : public SlotNumber {